@@ -9,6 +9,44 @@ import logging
 import tempfile
 
 
+class Abstract_SAS(saspy.SASsession):
+    def __init__(self, sasobjsp_user,
+                       sasobjsp_pass,
+                       sasobjsp_host,
+                       sasobjsp_port,  **kwargs):
+        self.sasobjsp_host = sasobjsp_host
+        self.sasobjsp_port = sasobjsp_port
+        self.sasobjsp_user = sasobjsp_user
+        self.sasobjsp_pass = sasobjsp_pass
+        self.connected = False
+
+    def connect(self):
+        connection = get_sas_connect(sasobjsp_host=self.sasobjsp_host,
+                                     sasobjsp_port=self.sasobjsp_port,
+                                     sasobjsp_user=self.sasobjsp_user,
+                                     sasobjsp_pass=self.sasobjsp_pass)
+        if connection:
+            self.connected = True
+            return self
+
+    def disconnect(self):
+        if self.connected:
+            self.endsas()
+            self.connected = False
+
+    def read_dataset(self, libname, tablename):
+        df = self.sasdata2dataframe(table=tablename, libref=libname)
+        return df
+
+    def write_dataset(self, df, libname, tablename):
+        result = self.dataframe2sasdata(df=df, table=tablename, libref=libname)
+        return result
+
+    def show_libs(self):
+        libs = self.assigned_librefs()
+        return libs
+
+
 def get_sas_connect(sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass, java='/usr/bin/java'):
     saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
     saspy_conn.write(f"""SAS_config_names=['sasconnection']
